@@ -69,14 +69,16 @@ class Fetch():
                         # append failed task to pending tasks
                         pending_tasks.add(new_task)
                     else:
-                        parse_func(task.result())
+                        resp = task.result()
+                        self.data.append(
+                            parse_func(resp)
+                        )
 
 
     def __call__(self, urls: list, method: str, parse_func: Callable) -> List[str]:
-        start = time.perf_counter()
-        loop = asyncio.get_event_loop()
-        loop.run_until_complete(self._master_req(urls, method, parse_func))
-        end = time.perf_counter(end - start)
+        self._start = time.perf_counter()
+        asyncio.run(self._master_req(urls, method, parse_func))
+        self._end = time.perf_counter()
 
     def __str__(self):
-        return "Time taken to execute: {:.2f}".format()
\ No newline at end of file
+        return "Time taken to execute: {:.2f}".format(self._end - self._start)
\ No newline at end of file
