@@ -7,12 +7,11 @@ data = [] #how to store data. Note! It has to be compatible with parse function
 
 fetcher = Fetch(REQUESTS_PER_SEC, data, SHOW_RESULTS)
 
-URLS = ['SOME URLS'] 
+URLS = ['https://ru.wikipedia.org/wiki/%D0%92%D0%B8%D0%BA%D0%B8']*10
 
-def parse_func(parser_instance, response):
-    """DO SOME PARSING HERE AND RETURN WHAT YOU WANT"""
-    """UPDATE parser_instance.data - this is where your data is stored""" 
+def parse_func(response):
     return response
 
 fetcher(URLS, "GET", parse_func)
-fetcher.data # -> output your data
\ No newline at end of file
+print(fetcher.data) # -> output your data
+print(fetcher) # -> check how much time was taken to execute
\ No newline at end of file
